==> haskell-http-conduit-2.3.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.3.1
id: http-conduit-2.3.1-4iDIlRPaKWA3DjnWm9PFHX
key: http-conduit-2.3.1-4iDIlRPaKWA3DjnWm9PFHX
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
abi: b960be73da1eb42682727790e6d9a380
exposed: True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-conduit-2.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-conduit-2.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-conduit-2.3.1
hs-libraries: HShttp-conduit-2.3.1-4iDIlRPaKWA3DjnWm9PFHX
depends:
    base-4.11.1.0 aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi
    bytestring-0.10.8.2 transformers-0.5.5.0
    resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8
    conduit-1.3.0.3-5ZsOzo28L26JRNfLzW387B
    conduit-extra-1.3.0-9iZ2LB1eD9H8KsHdGnB1z6
    http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX
    http-client-0.5.13-oP0CuDy48eCryfgf9zAeZ
    http-client-tls-0.3.5.3-87ITordiFeaJxpRGoXUThe mtl-2.2.2
    unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             aeson-1.3.1.1-J1bdggn8TZj5jjcHYxM7mi=4bd33a472ed49d1f25a046c18b4acb2d
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             resourcet-1.2.1-4pMMS1UB6fR4Ip7CV9uWB8=ac43be68d39189ee09e7e4402242c3d2
             conduit-1.3.0.3-5ZsOzo28L26JRNfLzW387B=4f322a960d59e7167ba56eb1269967d6
             conduit-extra-1.3.0-9iZ2LB1eD9H8KsHdGnB1z6=2a832346ef3320ea1578ea9d7d562aeb
             http-types-0.12.1-AvwTvixVY2aCGvkbFE4VfX=c36ea90c1caed733a7293143960ab603
             http-client-0.5.13-oP0CuDy48eCryfgf9zAeZ=dd5944a929261e121fef45baf41c85c5
             http-client-tls-0.3.5.3-87ITordiFeaJxpRGoXUThe=9d0acec7e2888a2f6d8681c2ef67bb98
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=900e31672c80ab97985a6f7a2b7fa053
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.3.1-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.3.1
id: http-conduit-2.3.1-KmBsjkCstWWJ7UXXOZmVum
key: http-conduit-2.3.1-KmBsjkCstWWJ7UXXOZmVum
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
abi: 7e3564423914df8c4aca9982ea424cc4
exposed: True
exposed-modules:
    Network.HTTP.Client.Conduit Network.HTTP.Conduit
    Network.HTTP.Simple
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-conduit-2.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-conduit-2.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-conduit-2.3.1
hs-libraries: HShttp-conduit-2.3.1-KmBsjkCstWWJ7UXXOZmVum
depends:
    base-4.11.1.0 aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73
    bytestring-0.10.8.2 transformers-0.5.5.0
    resourcet-1.2.1-DyrMduhw6NcBH9776LSX58
    conduit-1.3.0.3-DNtrSU95FR1AYBGJVSsEmb
    conduit-extra-1.3.0-AxLDH7YCnj68kqWhZGOQ6T
    http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq
    http-client-0.5.13-BDPgLPnNEzzAG7Py70CdWs
    http-client-tls-0.3.5.3-4gGcoaLAGPL3I1eY2hx2qR mtl-2.2.2
    unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             aeson-1.3.1.1-IVr04sg3p2P8j1rEsumT73=a6f953f9dda8218f3e00f48fbc968e32
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             resourcet-1.2.1-DyrMduhw6NcBH9776LSX58=5ef1111b0548768da5656735a567125c
             conduit-1.3.0.3-DNtrSU95FR1AYBGJVSsEmb=46bdf6011700b0b13e1de91dd938b40b
             conduit-extra-1.3.0-AxLDH7YCnj68kqWhZGOQ6T=b07ac46fa244d53e47c5b6bcbcbaff56
             http-types-0.12.1-JKNhfG7jJHdF2kQzyobEJq=681a4d4f5ae8e517c4372dabe00b35c0
             http-client-0.5.13-BDPgLPnNEzzAG7Py70CdWs=fa6eec72c73742ffff505285f6de59d8
             http-client-tls-0.3.5.3-4gGcoaLAGPL3I1eY2hx2qR=85b26cc28437727851175622157afe50
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=900e31672c80ab97985a6f7a2b7fa053
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
